SidePanel

Type Alias SidePanel 

pub type SidePanel = Panel;
👎Deprecated: Use Panel::left or Panel::right instead

Aliased Type

pub struct SidePanel {
    side: PanelSide,
    id: Id,
    frame: Option<Frame>,
    resizable: bool,
    show_separator_line: bool,
    default_size: Option<f32>,
    size_range: Rangef,
}

Fields

side: PanelSideid: Idframe: Option<Frame>resizable: boolshow_separator_line: booldefault_size: Option<f32>

The size is defined as being either the width for a Vertical Panel or the height for a Horizontal Panel.

size_range: Rangef

The size is defined as being either the width for a Vertical Panel or the height for a Horizontal Panel.